@@ -38,11 +38,16 @@ class ImageGen:
         print("Sending request...")
         url_encoded_prompt = urllib.parse.quote(prompt)
         # https://www.bing.com/images/create?q=<PROMPT>&rt=3&FORM=GENCRE
-        url = f"{BING_URL}/images/create?q={url_encoded_prompt}&rt=3&FORM=GENCRE"
+        url = f"{BING_URL}/images/create?q={url_encoded_prompt}&rt=4&FORM=GENCRE"
         response = self.session.post(url, allow_redirects=False)
         if response.status_code != 302:
-            print(f"ERROR: {response.text}")
-            raise Exception("Redirect failed")
+            #if rt4 fails, try rt3
+            url= f"{BING_URL}/images/create?q={url_encoded_prompt}&rt=3&FORM=GENCRE"
+            response3 = self.session.post(url, allow_redirects=False, timeout=200)
+            if response3.status_code != 302:
+                    print(f"ERROR: {response3.text}")
+                    raise Exception("Redirect failed")
+            response=response3
         # Get redirect URL
         redirect_url = response.headers["Location"].replace("&nfy=1", "")
         request_id = redirect_url.split("id=")[-1]
@@ -64,8 +69,10 @@ class ImageGen:
 
         # Use regex to search for src=""
         image_links = regex.findall(r'src="([^"]+)"', response.text)
+        # Remove size limit
+        normal_image_links = [link.split("?w=")[0] for link in image_links]
         # Remove duplicates
-        return list(set(image_links))
+        return list(set(normal_image_links))
 
     def save_images(self, links: list, output_dir: str) -> None:
         """
@@ -77,15 +84,18 @@ class ImageGen:
         except FileExistsError:
             pass
         image_num = 0
-        for link in links:
-            with self.session.get(link, stream=True) as response:
-                # save response to file
-                response.raise_for_status()
-                with open(f"{output_dir}/{image_num}.jpeg", "wb") as output_file:
-                    for chunk in response.iter_content(chunk_size=8192):
-                        output_file.write(chunk)
+        try:
+            for link in links:
+                with self.session.get(link, stream=True) as response:
+                    # save response to file
+                    response.raise_for_status()
+                    with open(f"{output_dir}/{image_num}.jpeg", "wb") as output_file:
+                        for chunk in response.iter_content(chunk_size=8192):
+                            output_file.write(chunk)
 
-            image_num += 1
+                image_num += 1
+        except requests.exceptions.MissingSchema as url_exception:
+            raise Exception('Inappropriate contents found in the generated images. Please try again or try another prompt.') from url_exception
 
 
 if __name__ == "__main__":
